@@ -3,10 +3,10 @@
 
 from . import libswn as swn
 from .workday import *
+from .database import *
 
 import datetime,time,inspect,collections,hashlib,base64,urllib.request,json,subprocess
 import os,re,shutil,smtplib,sys,getpass
-from . import liblocalval as lval
 from email import encoders
 
 dqrq12=time.strftime('%Y%m%d',time.localtime(time.time()-12*3600))
@@ -173,48 +173,6 @@ class c_commandarg: #根据命令行参数调用模块及显示相应help
         for name in scmd:
             print("%-*s   %s" %(maxcmdsize,name,c_commandarg.tcmd[name].__doc__))
 
-class webapi(object):
-    def __init__(self):
-        prefix=os.environ.get("envprefix","")
-        if prefix=="":
-            swexit(1,"必须设置环境变量 envprefix")
-        user=swenv("user","")
-        if user=="":
-            user=input("输入确认身份用的用户名:")
-        passwd=swenv("passwd","")
-        if passwd=="":
-            passwd=getpass.getpass("输入密码:")
-        self.sj={}
-        self.sj["pubLevel"]="0"
-        self.sj["updateBy"]=user
-        self.sj["passwd"]=passwd
-    def up(self,fn):#上传文件
-        self.url=lval.apiserver[getarg(2)]["up"]
-        self.sj["md5"]=filemd5(fn)
-        self.sj["script"]=base64encode(fn).decode("utf8")
-        self.sj["svcname"]=fn.split("/")[-1]
-        print(fn,end="   ")
-        jg=self.get()
-        if jg["code"]==0:
-            print("上传成功")
-            
-    def down(self,fn):#下载文件
-        self.url=lval.apiserver[getarg(2)]["down"]
-        self.sj["svcname"]=fn.split("/")[-1]
-        return self.get()
-    def get(self):  #获取数据
-        data=json.dumps(self.sj,ensure_ascii=False,skipkeys=False).encode("utf8")
-        headers={'Accept-Charset': 'utf-8', 'Content-Type': 'application/json'}
-        req =  urllib.request.Request(self.url,data=data,headers=headers,method='POST')
-        res_data = urllib.request.urlopen(req)
-        res = res_data.read()
-        jg=json.loads(res.decode("utf8"))
-        if jg["code"]==404:
-            redp("服务器不存在此脚本")
-        elif jg["code"]!=0:
-            print(jg)
-        return jg
-
 def redp(s):
     print("\x1b[0;31;40m%s\x1b[0m" %(s))
 
@@ -242,160 +200,6 @@ def onlyone():  #实例仅运行一次，如果有多于1个则退出运行
         print("有多于一个的实例，退出")
         sys.exit(1)
 
-class c_oracle(object):
-    def __init__(self,sconn="",yslj=False,autocommit=False,raiseExp=False):
-        global cx_Oracle
-        import cx_Oracle
-        self.sconn=sconn
-        self.connected=False
-        self.autocommit=autocommit
-        self.raiseExp = raiseExp
-        (not yslj) and self.connect()
-    def commit(self):
-        try:
-            self.conn.commit()
-        except cx_Oracle.DatabaseError as e:
-            print("commit异常：%s" % (e))
-            error, = e.args
-            if error.code==28 or error.code==1012:  #未登录或者被踢出
-                self.connected=False
-            if self.raiseExp:
-                raise  # 往上层抛
-    def connect(self,sconn=""):
-        if sconn!="":
-            self.sconn=sconn
-            self.connected=False
-        if self.connected:
-            c=self.conn.cursor()
-            try:
-                c.execute("select 1 from dual")
-            except cx_Oracle.DatabaseError as e:
-                self.connected=False
-                print("连接数据库异常：%s" % (e))
-                if self.raiseExp:
-                    raise  # 往上层抛
-            else:
-                return
-        try:
-            self.conn=cx_Oracle.connect(self.convconn(self.sconn))
-        except cx_Oracle.DatabaseError as e:
-            swexit(1,"数据库连接%s不成功" %(self.sconn))
-            error, = e.args
-            if self.raiseExp:
-                raise  # 往上层抛
-        else:
-            self.c=self.conn.cursor()
-            self.connected=True
-    def convconn(self,ljc):
-        if ljc.find("/")>0:
-            return ljc
-        f=open("/etc/oraconn.cfg")
-        wjnr=f.readlines()
-        f.close()
-        for i in wjnr:
-            s=i.split()
-            if len(s)<2:
-                continue
-            if s[0]==ljc:
-                return s[1]
-        return ""
-    def droptable(self,tablename):
-        if self.jg1("select count(1) from user_tables where table_name = upper('%s')" %(tablename))==1:
-            self.c.execute("drop table %s purge" %(tablename))
-    def execute(self,ssql,*args,**kwargs):
-        (not self.connected) and self.connect()
-        if not self.connected:
-            return
-        try:
-            c=self.conn.cursor()
-            c.execute(ssql,*args,**kwargs)
-        except cx_Oracle.DatabaseError as e:
-            self.connected=False
-            print("oracle执行异常：%s" % (e))
-            if self.raiseExp:
-                raise  # 往上层抛
-            return
-        return c
-    def execute2(self,ssql,**kwargs):
-        (not self.connected) and self.connect()
-        if not self.connected:
-            return
-        try:
-            list = []
-            c = self.conn.cursor()
-            c.execute(ssql, kwargs)
-            col = c.description
-            for item in c.fetchall():
-                dict = {}
-                for i in range(len(col)):
-                    dict[col[i][0]] = item[i]
-                list.append(dict)
-        except cx_Oracle.DatabaseError as e:
-            self.connected = False
-            print("oracle执行异常：%s" % (e))
-            if self.raiseExp:
-                raise  # 往上层抛
-            return
-        return list
-    def inslist(self,tablename,data,collist=""):
-        '''在表中直接插入数据'''
-        (not self.connected) and self.connect()
-        if collist=="":
-            ssql="insert into %s values(" %(tablename)
-        else:
-            ssql="insert into %s (%s) values(" %(tablename,collist)
-        for i in range(len(data)):
-            ssql="%s:%d," %(ssql,i)
-        ssql="%s)" %(ssql[:-1])
-        c=self.conn.cursor()
-        c.execute(ssql,data)
-    def jg1(self,ssql,*args,**kwargs):
-        '''根据sql返回1条结果'''
-        (not self.connected) and self.connect()
-        if not self.connected:
-            return
-        try:
-            c=self.conn.cursor()
-            c.execute(ssql,*args,**kwargs)
-            jg=c.fetchone()
-        except cx_Oracle.DatabaseError as e:
-            self.connected=False
-            print("oracle执行异常：%s" % (e))
-            if self.raiseExp:
-                raise  # 往上层抛
-            return
-        c.close()
-        if jg==None:
-            return
-        if len(jg)==1:
-            return jg[0]
-        else:
-            return jg
-    def tablecreatesql(self,tablename): #获取表的生成脚本
-        c=self.conn.cursor()
-        c.callproc('DBMS_METADATA.SET_TRANSFORM_PARAM',(-1, 'TABLESPACE',False))
-        c.callproc("DBMS_METADATA.SET_TRANSFORM_PARAM",(-1,'STORAGE',False))
-        c.callproc("DBMS_METADATA.SET_TRANSFORM_PARAM",(-1,'SEGMENT_ATTRIBUTES',False))
-        c.callproc("DBMS_METADATA.SET_TRANSFORM_PARAM",(-1,'PRETTY',False))
-        ssql=self.jg1("SELECT dbms_metadata.get_ddl('TABLE','%s') FROM DUAL" %(tablename.upper())).read()
-        ssql='create table "%s" %s' %(tablename.upper(),ssql[ssql.find("("):])
-        return ssql
-    def xg(self,ssql,**kwargs): #对数据库进行修改，可自动commit
-        (not self.connected) and self.connect()
-        if not self.connected:
-            return
-        try:
-            c=self.conn.cursor()
-            c.execute(ssql,kwargs)
-            self.autocommit and self.commit()
-        except cx_Oracle.DatabaseError as e:
-            self.connected=False
-            print("oracle执行异常：%s" %(e))
-            if self.raiseExp:
-                raise  # 往上层抛
-            return
-        return True
-
 class taora(c_oracle):
     def __init__(self,ta="hsta",changeable=False):
         self.ta=ta
@@ -598,6 +402,7 @@ def swexit(returncode,msg="",nextchecktime=""): #事务退出环节
         if rqlx==3: #日期类型为3，不按日期
             swrq=dqrq
         swdb.execute("update sw set rtncode=0,rtnmsg='',locker='',nextcheck=to_date(:jcsj,'yyyymmddhh24miss'),swrq=:swrq,status=swtype where id=:swid",swid=swid,swrq=swrq,jcsj=jcsj)
+        swdb.execute("update sw_dispath set use_time=(sysdate-dispath_time)*24*3600 where dispathno=:dispathno and swid=:swid",dispathno=logid,swid=swid)
     elif returncode<0:  #返回码为负，异常退出
         swdb.execute("update sw set rtncode=:rtcode,rtnmsg=:rtmsg,locker='',status=2 where id=:swid",rtcode=returncode,rtmsg=msg,swid=swid)
     else:   #返回码为正，多半是条件不满足
